==> kdeutils_4.4.5.orig.tar.bz2: kdeutils-4.4.5/okteta/kasten/controllers/view/structures/datatypes/bool64datainformation.h <==
/*
 *   This file is part of the Okteta Kasten module, part of the KDE project.
 *
 *   Copyright 2009 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef BOOL64DATAINFORMATION_H_
#define BOOL64DATAINFORMATION_H_

#include "unsignedprimitivedatainformation.h"
#include "../poddecoder/typeeditors/uint64editor.h"

class Bool64DataInformation: public UnsignedPrimitiveDataInformation
{
PRIMITIVEDATAINFORMATION_SUBCLASS_CONSTRUCTORS(Bool64,UnsignedPrimitive)

public:
    inline int getSize() const
    {
        return 64;
    }
    inline QString getTypeName() const
    {
        return i18nc("Data type", "bool (8 bytes)");
    }
    DATAINFORMATION_CLONE(Bool64)
    virtual QString getValueString() const;

    inline QWidget* createEditWidget(QWidget* parent) const
    {
        UInt64Editor* ret = new UInt64Editor(parent);
        ret->setBase(displayBase());
        return ret;
    }
};

#endif /* BOOL64DATAINFORMATION_H_ */

==> kdeutils-4.5.1.tar.bz2: kdeutils-4.5.1/okteta/kasten/controllers/view/structures/datatypes/bool64datainformation.h <==
/*
 *   This file is part of the Okteta Kasten Framework, part of the KDE project.
 *
 *   Copyright 2009, 2010 Alex Richardson <alex.richardson@gmx.de>
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or (at your option) version 3, or any
 *   later version accepted by the membership of KDE e.V. (or its
 *   successor approved by the membership of KDE e.V.), which shall
 *   act as a proxy defined in Section 6 of version 3 of the license.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef BOOL64DATAINFORMATION_H_
#define BOOL64DATAINFORMATION_H_

#include "unsignedprimitivedatainformation.h"
#include "../poddecoder/typeeditors/uint64editor.h"

class Bool64DataInformation: public UnsignedPrimitiveDataInformation
{
Q_OBJECT
PRIMITIVEDATAINFORMATION_SUBCLASS_CONSTRUCTORS(Bool64,UnsignedPrimitive)

public:
    DATAINFORMATION_CLONE(Bool64)

    int size() const;
    QString typeName() const;
    virtual QString valueString() const;

    QWidget* createEditWidget(QWidget* parent) const;
};

inline QString Bool64DataInformation::typeName() const
{
    return i18nc("Data type", "bool (8 bytes)");
}

inline int Bool64DataInformation::size() const
{
    return 64;
}

#endif /* BOOL64DATAINFORMATION_H_ */
